from setuptools import setup, find_packages

setup(
    name='djcolour',
    description='Automatically use `colour.Color` in Python, `django.db.models.CharField` on the database, and `<input type="color">` on the forms.',
    url='https://github.com/jansegre/djcolour',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'colour>=0.1.4,<0.2',
    ],
    author='Jan Segre',
    author_email='jan@segre.in',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django :: 1.11',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)



from django.core.exceptions import ValidationError
from django.db import models
from django.utils.translation import ugettext_lazy as _

from .base import Color
from .forms.fields import ColorField as ColorFormField


def parse_color(color_string):
    try:
        return Color(color_string)
    except ValueError as v:
        raise ValidationError(_('\'%s\' is not recognized as a valid color') % (color_string,))


class ColorField(models.Field):

    description = "Represent a color using colour.Color"

    def __init__(self, *args, **kwargs):
        defaults = {'max_length': 7}
        defaults.update(kwargs)
        super(ColorField, self).__init__(*args, **defaults)

    def from_db_value(self, value, expression, connection, context):
        if value is None:
            return value
        return parse_color(value)

    def to_python(self, value):
        if isinstance(value, Color):
            return value

        if value is None:
            return value

        return value

    def formfield(self, **kwargs):
        defaults = {'form_class': ColorFormField}
        defaults.update(kwargs)
        return super(ColorField, self).formfield(**defaults)
